<!DOCTYPE html><htmllang="en"><head><metacharset="utf-8"><metaname="viewport"content="width=device-width, initial-scale=1.0"><metaname="generator"content="rustdoc"><metaname="description"content="A word of Rust code, which may be a keyword or legal variable name."><title>Ident in proc_macro2 - Rust</title><script>if(window.location.protocol!=="file:")document.head.insertAdjacentHTML("beforeend","SourceSerif4-Regular-6b053e98.ttf.woff2,FiraSans-Italic-81dc35de.woff2,FiraSans-Regular-0fe48ade.woff2,FiraSans-MediumItalic-ccf7e434.woff2,FiraSans-Medium-e1aa3f0a.woff2,SourceCodePro-Regular-8badfe75.ttf.woff2,SourceCodePro-Semibold-aa29a496.ttf.woff2".split(",").map(f=>`<link rel="preload" as="font" type="font/woff2" crossorigin href="../static.files/${f}">`).join(""))</script><linkrel="stylesheet"href="../static.files/normalize-9960930a.css"><linkrel="stylesheet"href="../static.files/rustdoc-84e720fa.css"><metaname="rustdoc-vars"data-root-path="../"data-static-root-path="../static.files/"data-current-crate="proc_macro2"data-themes=""data-resource-suffix=""data-rustdoc-version="1.89.0 (29483883e 2025-08-04)"data-channel="1.89.0"data-search-js="search-92309212.js"data-settings-js="settings-5514c975.js"><scriptsrc="../static.files/storage-4e99c027.js"></script><scriptdefersrc="sidebar-items.js"></script><scriptdefersrc="../static.files/main-fd3af306.js"></script><noscript><linkrel="stylesheet"href="../static.files/noscript-32bb7600.css"></noscript><linkrel="alternate icon"type="image/png"href="../static.files/favicon-32x32-6580c154.png"><linkrel="icon"type="image/svg+xml"href="../static.files/favicon-044be391.svg"></head><bodyclass="rustdoc struct"><!--[if lte IE 11]><div class="warning">This old browser is unsupported and will most likely display funky things.</div><![endif]--><navclass="mobile-topbar"><buttonclass="sidebar-menu-toggle"title="show sidebar"></button></nav><navclass="sidebar"><divclass="sidebar-crate"><h2><ahref="../proc_macro2/index.html">proc_<wbr>macro2</a><spanclass="version">1.0.101</span></h2></div><divclass="sidebar-elems"><sectionid="rustdoc-toc"><h2class="location"><ahref="#">Ident</a></h2><h3><ahref="#">Sections</a></h3><ulclass="block top-toc"><li><ahref="#examples"title="Examples">Examples</a></li></ul><h3><ahref="#implementations">Methods</a></h3><ulclass="block method"><li><ahref="#method.new"title="new">new</a></li><li><ahref="#method.new_raw"title="new_raw">new_raw</a></li><li><ahref="#method.set_span"title="set_span">set_span</a></li><li><ahref="#method.span"title="span">span</a></li></ul><h3><ahref="#trait-implementations">Trait Implementations</a></h3><ulclass="block trait-implementation"><li><ahref="#impl-Clone-for-Ident"title="Clone">Clone</a></li><li><ahref="#impl-Debug-for-Ident"title="Debug">Debug</a></li><li><ahref="#impl-Display-for-Ident"title="Display">Display</a></li><li><ahref="#impl-Eq-for-Ident"title="Eq">Eq</a></li><li><ahref="#impl-From%3CIdent%3E-for-TokenTree"title="From<Ident>">From<Ident></a></li><li><ahref="#impl-Hash-for-Ident"title="Hash">Hash</a></li><li><ahref="#impl-Ord-for-Ident"title="Ord">Ord</a></li><li><ahref="#impl-PartialEq-for-Ident"title="PartialEq">PartialEq</a></li><li><ahref="#impl-PartialEq%3CT%3E-for-Ident"title="PartialEq<T>">PartialEq<T></a></li><li><ahref="#impl-PartialOrd-for-Ident"title="PartialOrd">PartialOrd</a></li></ul><h3><ahref="#synthetic-implementations">Auto Trait Implementations</a></h3><ulclass="block synthetic-implementation"><li><ahref="#impl-Send-for-Ident"title="!Send">!Send</a></li><li><ahref="#impl-Sync-for-Ident"title="!Sync">!Sync</a></li><li><ahref="#impl-Freeze-for-Ident"title="Freeze">Freeze</a></li><li><ahref="#impl-RefUnwindSafe-for-Ident"title="RefUnwindSafe">RefUnwindSafe</a></li><li><ahref="#impl-Unpin-for-Ident"title="Unpin">Unpin</a></li><li><ahref="#impl-UnwindSafe-for-Ident"title="UnwindSafe">UnwindSafe</a></li></ul><h3><ahref="#blanket-implementations">Blanket Implementations</a></h3><ulcl
</div></details><h2id="implementations"class="section-header">Implementations<ahref="#implementations"class="anchor"></a></h2><divid="implementations-list"><detailsclass="toggle implementors-toggle"open><summary><sectionid="impl-Ident"class="impl"><aclass="src rightside"href="../src/proc_macro2/lib.rs.html#928-999">Source</a><ahref="#impl-Ident"class="anchor"></a><h3class="code-header">impl <aclass="struct"href="struct.Ident.html"title="struct proc_macro2::Ident">Ident</a></h3></section></summary><divclass="impl-items"><detailsclass="toggle method-toggle"open><summary><sectionid="method.new"class="method"><aclass="src rightside"href="../src/proc_macro2/lib.rs.html#975-977">Source</a><h4class="code-header">pub fn <ahref="#method.new"class="fn">new</a>(string: &<aclass="primitive"href="https://doc.rust-lang.org/1.89.0/std/primitive.str.html">str</a>, span: <aclass="struct"href="struct.Span.html"title="struct proc_macro2::Span">Span</a>) -> Self</h4></section></summary><divclass="docblock"><p>Creates a new <code>Ident</code> with the given <code>string</code> as well as the specified
</div></details><detailsclass="toggle method-toggle"open><summary><sectionid="method.new_raw"class="method"><aclass="src rightside"href="../src/proc_macro2/lib.rs.html#985-987">Source</a><h4class="code-header">pub fn <ahref="#method.new_raw"class="fn">new_raw</a>(string: &<aclass="primitive"href="https://doc.rust-lang.org/1.89.0/std/primitive.str.html">str</a>, span: <aclass="struct"href="struct.Span.html"title="struct proc_macro2::Span">Span</a>) -> Self</h4></section></summary><divclass="docblock"><p>Same as <code>Ident::new</code>, but creates a raw identifier (<code>r#ident</code>). The
</div></details><detailsclass="toggle method-toggle"open><summary><sectionid="method.span"class="method"><aclass="src rightside"href="../src/proc_macro2/lib.rs.html#990-992">Source</a><h4class="code-header">pub fn <ahref="#method.span"class="fn">span</a>(&self) -><aclass="struct"href="struct.Span.html"title="struct proc_macro2::Span">Span</a></h4></section></summary><divclass="docblock"><p>Returns the span of this <code>Ident</code>.</p>
</div></details><detailsclass="toggle method-toggle"open><summary><sectionid="method.set_span"class="method"><aclass="src rightside"href="../src/proc_macro2/lib.rs.html#996-998">Source</a><h4class="code-header">pub fn <ahref="#method.set_span"class="fn">set_span</a>(&mut self, span: <aclass="struct"href="struct.Span.html"title="struct proc_macro2::Span">Span</a>)</h4></section></summary><divclass="docblock"><p>Configures the span of this <code>Ident</code>, possibly changing its hygiene
</div></section></summary><divclass="impl-items"><detailsclass="toggle method-toggle"open><summary><sectionid="method.fmt"class="method trait-impl"><aclass="src rightside"href="../src/proc_macro2/lib.rs.html#1039-1041">Source</a><ahref="#method.fmt"class="anchor"></a><h4class="code-header">fn <ahref="https://doc.rust-lang.org/1.89.0/core/fmt/trait.Display.html#tymethod.fmt"class="fn">fmt</a>(&self, f: &mut <aclass="struct"href="https://doc.rust-lang.org/1.89.0/core/fmt/struct.Formatter.html"title="struct core::fmt::Formatter">Formatter</a><'_>) -><aclass="type"href="https://doc.rust-lang.org/1.89.0/core/fmt/type.Result.html"title="type core::fmt::Result">Result</a></h4></section></summary><divclass='docblock'>Formats the value using the given formatter. <ahref="https://doc.rust-lang.org/1.89.0/core/fmt/trait.Display.html#tymethod.fmt">Read more</a></div></details></div></details><detailsclass="toggle implementors-toggle"open><summary><sectionid="impl-From%3CIdent%3E-for-TokenTree"class="impl"><aclass="src rightside"href="../src/proc_macro2/lib.rs.html#577-581">Source</a><ahref="#impl-From%3CIdent%3E-for-TokenTree"class="anchor"></a><h3class="code-header">impl <aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/convert/trait.From.html"title="trait core::convert::From">From</a><<aclass="struct"href="struct.Ident.html"title="struct proc_macro2::Ident">Ident</a>> for <aclass="enum"href="enum.TokenTree.html"title="enum proc_macro2::TokenTree">TokenTree</a></h3></section></summary><divclass="impl-items"><detailsclass="toggle method-toggle"open><summary><sectionid="method.from"class="method trait-impl"><aclass="src rightside"href="../src/proc_macro2/lib.rs.html#578-580">Source</a><ahref="#method.from"class="anchor"></a><h4class="code-header">fn <ahref="https://doc.rust-lang.org/1.89.0/core/convert/trait.From.html#tymethod.from"class="fn">from</a>(g: <aclass="struct"href="struct.Ident.html"title="struct proc_macro2::Ident">Ident</a>) -> Self</h4></section></summary><divclass='docblock'>Converts to this type from the input type.</div></details></div></details><detailsclass="toggle implementors-toggle"open><summary><sectionid="impl-Hash-for-Ident"class="impl"><aclass="src rightside"href="../src/proc_macro2/lib.rs.html#1030-1034">Source</a><ahref="#impl-Hash-for-Ident"class="anchor"></a><h3class="code-header">impl <aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/hash/trait.Hash.html"title="trait core::hash::Hash">Hash</a> for <aclass="struct"href="struct.Ident.html"title="struct proc_macro2::Ident">Ident</a></h3></section></summary><divclass="impl-items"><detailsclass="toggle method-toggle"open><summary><sectionid="method.hash"class="method trait-impl"><aclass="src rightside"href="../src/proc_macro2/lib.rs.html#1031-1033">Source</a><ahref="#method.hash"class="anchor"></a><h4class="code-header">fn <ahref="https://doc.rust-lang.org/1.89.0/core/hash/trait.Hash.html#tymethod.hash"class="fn">hash</a><H: <aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/hash/trait.Hasher.html"title="trait core::hash::Hasher">Hasher</a>>(&self, hasher: <aclass="primitive"href="https://doc.rust-lang.org/1.89.0/std/primitive.reference.html">&mut H</a>)</h4></section></summary><divclass='docblock'>Feeds this value into the given <ahref="https://doc.rust-lang.org/1.89.0/core/hash/trait.Hasher.html"title="trait core::hash::Hasher"><code>Hasher</code></a>. <ahref="https://doc.rust-lang.org/1.89.0/core/hash/trait.Hash.html#tymethod.hash">Read more</a></div></details><detailsclass="toggle method-toggle"open><summary><sectionid="method.hash_slice"class="method trait-impl"><spanclass="rightside"><spanclass="since"title="Stable since Rust version 1.3.0">1.3.0</span> · <aclass="src"href="https://doc.rust-lang.org/1.89.0/src/core/hash/mod.rs.html#235-237">Source</a></span><ahref="#method.hash_slice"class="anchor"></a><h4class="code-header">fn <ahref="https://doc.rust-lang.org/1.89.0/core
Self: <aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/marker/trait.Sized.html"title="trait core::marker::Sized">Sized</a>,</div></h4></section></summary><divclass='docblock'>Feeds a slice of this type into the given <ahref="https://doc.rust-lang.org/1.89.0/core/hash/trait.Hasher.html"title="trait core::hash::Hasher"><code>Hasher</code></a>. <ahref="https://doc.rust-lang.org/1.89.0/core/hash/trait.Hash.html#method.hash_slice">Read more</a></div></details></div></details><detailsclass="toggle implementors-toggle"open><summary><sectionid="impl-Ord-for-Ident"class="impl"><aclass="src rightside"href="../src/proc_macro2/lib.rs.html#1024-1028">Source</a><ahref="#impl-Ord-for-Ident"class="anchor"></a><h3class="code-header">impl <aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/cmp/trait.Ord.html"title="trait core::cmp::Ord">Ord</a> for <aclass="struct"href="struct.Ident.html"title="struct proc_macro2::Ident">Ident</a></h3></section></summary><divclass="impl-items"><detailsclass="toggle method-toggle"open><summary><sectionid="method.cmp"class="method trait-impl"><aclass="src rightside"href="../src/proc_macro2/lib.rs.html#1025-1027">Source</a><ahref="#method.cmp"class="anchor"></a><h4class="code-header">fn <ahref="https://doc.rust-lang.org/1.89.0/core/cmp/trait.Ord.html#tymethod.cmp"class="fn">cmp</a>(&self, other: &<aclass="struct"href="struct.Ident.html"title="struct proc_macro2::Ident">Ident</a>) -><aclass="enum"href="https://doc.rust-lang.org/1.89.0/core/cmp/enum.Ordering.html"title="enum core::cmp::Ordering">Ordering</a></h4></section></summary><divclass='docblock'>This method returns an <ahref="https://doc.rust-lang.org/1.89.0/core/cmp/enum.Ordering.html"title="enum core::cmp::Ordering"><code>Ordering</code></a> between <code>self</code> and <code>other</code>. <ahref="https://doc.rust-lang.org/1.89.0/core/cmp/trait.Ord.html#tymethod.cmp">Read more</a></div></details><detailsclass="toggle method-toggle"open><summary><sectionid="method.max"class="method trait-impl"><spanclass="rightside"><spanclass="since"title="Stable since Rust version 1.21.0">1.21.0</span> · <aclass="src"href="https://doc.rust-lang.org/1.89.0/src/core/cmp.rs.html#1010-1012">Source</a></span><ahref="#method.max"class="anchor"></a><h4class="code-header">fn <ahref="https://doc.rust-lang.org/1.89.0/core/cmp/trait.Ord.html#method.max"class="fn">max</a>(self, other: Self) -> Self<divclass="where">where
Self: <aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/marker/trait.Sized.html"title="trait core::marker::Sized">Sized</a>,</div></h4></section></summary><divclass='docblock'>Compares and returns the maximum of two values. <ahref="https://doc.rust-lang.org/1.89.0/core/cmp/trait.Ord.html#method.max">Read more</a></div></details><detailsclass="toggle method-toggle"open><summary><sectionid="method.min"class="method trait-impl"><spanclass="rightside"><spanclass="since"title="Stable since Rust version 1.21.0">1.21.0</span> · <aclass="src"href="https://doc.rust-lang.org/1.89.0/src/core/cmp.rs.html#1049-1051">Source</a></span><ahref="#method.min"class="anchor"></a><h4class="code-header">fn <ahref="https://doc.rust-lang.org/1.89.0/core/cmp/trait.Ord.html#method.min"class="fn">min</a>(self, other: Self) -> Self<divclass="where">where
Self: <aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/marker/trait.Sized.html"title="trait core::marker::Sized">Sized</a>,</div></h4></section></summary><divclass='docblock'>Compares and returns the minimum of two values. <ahref="https://doc.rust-lang.org/1.89.0/core/cmp/trait.Ord.html#method.min">Read more</a></div></details><detailsclass="toggle method-toggle"open><summary><sectionid="method.clamp"class="method trait-impl"><spanclass="rightside"><spanclass="since"title="Stable since Rust version 1.50.0">1.50.0</span> · <aclass="src"href="https://doc.rust-lang.org/1.89.0/src/core/cmp.rs.html#1075-1077">Source</a></span><ahref="#method.clamp"class="anchor"></a><h4class="code-header">fn <ahref="https://doc.rust-lang.org/1.89.0/core/cmp/trait.Ord.html#method.clamp"class="fn">clamp</a>(self, min: Self, max: Self) -> Self<divclass="where">where
Self: <aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/marker/trait.Sized.html"title="trait core::marker::Sized">Sized</a>,</div></h4></section></summary><divclass='docblock'>Restrict a value to a certain interval. <ahref="https://doc.rust-lang.org/1.89.0/core/cmp/trait.Ord.html#method.clamp">Read more</a></div></details></div></details><detailsclass="toggle implementors-toggle"open><summary><sectionid="impl-PartialEq%3CT%3E-for-Ident"class="impl"><aclass="src rightside"href="../src/proc_macro2/lib.rs.html#1007-1014">Source</a><ahref="#impl-PartialEq%3CT%3E-for-Ident"class="anchor"></a><h3class="code-header">impl<T><aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/cmp/trait.PartialEq.html"title="trait core::cmp::PartialEq">PartialEq</a><T> for <aclass="struct"href="struct.Ident.html"title="struct proc_macro2::Ident">Ident</a><divclass="where">where
T: ?<aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/marker/trait.Sized.html"title="trait core::marker::Sized">Sized</a> + <aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/convert/trait.AsRef.html"title="trait core::convert::AsRef">AsRef</a><<aclass="primitive"href="https://doc.rust-lang.org/1.89.0/std/primitive.str.html">str</a>>,</div></h3></section></summary><divclass="impl-items"><detailsclass="toggle method-toggle"open><summary><sectionid="method.eq-1"class="method trait-impl"><aclass="src rightside"href="../src/proc_macro2/lib.rs.html#1011-1013">Source</a><ahref="#method.eq-1"class="anchor"></a><h4class="code-header">fn <ahref="https://doc.rust-lang.org/1.89.0/core/cmp/trait.PartialEq.html#tymethod.eq"class="fn">eq</a>(&self, other: <aclass="primitive"href="https://doc.rust-lang.org/1.89.0/std/primitive.reference.html">&T</a>) -><aclass="primitive"href="https://doc.rust-lang.org/1.89.0/std/primitive.bool.html">bool</a></h4></section></summary><divclass='docblock'>Tests for <code>self</code> and <code>other</code> values to be equal, and is used by <code>==</code>.</div></details><detailsclass="toggle method-toggle"open><summary><sectionid="method.ne-1"class="method trait-impl"><spanclass="rightside"><spanclass="since"title="Stable since Rust version 1.0.0">1.0.0</span> · <aclass="src"href="https://doc.rust-lang.org/1.89.0/src/core/cmp.rs.html#263">Source</a></span><ahref="#method.ne-1"class="anchor"></a><h4class="code-header">fn <ahref="https://doc.rust-lang.org/1.89.0/core/cmp/trait.PartialEq.html#method.ne"class="fn">ne</a>(&self, other: <aclass="primitive"href="https://doc.rust-lang.org/1.89.0/std/primitive.reference.html">&Rhs</a>) -><aclass="primitive"href="https://doc.rust-lang.org/1.89.0/std/primitive.bool.html">bool</a></h4></section></summary><divclass='docblock'>Tests for <code>!=</code>. The default implementation is almost always sufficient,
and should not be overridden without very good reason.</div></details></div></details><detailsclass="toggle implementors-toggle"open><summary><sectionid="impl-PartialEq-for-Ident"class="impl"><aclass="src rightside"href="../src/proc_macro2/lib.rs.html#1001-1005">Source</a><ahref="#impl-PartialEq-for-Ident"class="anchor"></a><h3class="code-header">impl <aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/cmp/trait.PartialEq.html"title="trait core::cmp::PartialEq">PartialEq</a> for <aclass="struct"href="struct.Ident.html"title="struct proc_macro2::Ident">Ident</a></h3></section></summary><divclass="impl-items"><detailsclass="toggle method-toggle"open><summary><sectionid="method.eq"class="method trait-impl"><aclass="src rightside"href="../src/proc_macro2/lib.rs.html#1002-1004">Source</a><ahref="#method.eq"class="anchor"></a><h4class="code-header">fn <ahref="https://doc.rust-lang.org/1.89.0/core/cmp/trait.PartialEq.html#tymethod.eq"class="fn">eq</a>(&self, other: &<aclass="struct"href="struct.Ident.html"title="struct proc_macro2::Ident">Ident</a>) -><aclass="primitive"href="https://doc.rust-lang.org/1.89.0/std/primitive.bool.html">bool</a></h4></section></summary><divclass='docblock'>Tests for <code>self</code> and <code>other</code> values to be equal, and is used by <code>==</code>.</div></details><detailsclass="toggle method-toggle"open><summary><sectionid="method.ne"class="method trait-impl"><spanclass="rightside"><spanclass="since"title="Stable since Rust version 1.0.0">1.0.0</span> · <aclass="src"href="https://doc.rust-lang.org/1.89.0/src/core/cmp.rs.html#263">Source</a></span><ahref="#method.ne"class="anchor"></a><h4class="code-header">fn <ahref="https://doc.rust-lang.org/1.89.0/core/cmp/trait.PartialEq.html#method.ne"class="fn">ne</a>(&self, other: <aclass="primitive"href="https://doc.rust-lang.org/1.89.0/std/primitive.reference.html">&Rhs</a>) -><aclass="primitive"href="https://doc.rust-lang.org/1.89.0/std/primitive.bool.html">bool</a></h4></section></summary><divclass='docblock'>Tests for <code>!=</code>. The default implementation is almost always sufficient,
and should not be overridden without very good reason.</div></details></div></details><detailsclass="toggle implementors-toggle"open><summary><sectionid="impl-PartialOrd-for-Ident"class="impl"><aclass="src rightside"href="../src/proc_macro2/lib.rs.html#1018-1022">Source</a><ahref="#impl-PartialOrd-for-Ident"class="anchor"></a><h3class="code-header">impl <aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/cmp/trait.PartialOrd.html"title="trait core::cmp::PartialOrd">PartialOrd</a> for <aclass="struct"href="struct.Ident.html"title="struct proc_macro2::Ident">Ident</a></h3></section></summary><divclass="impl-items"><detailsclass="toggle method-toggle"open><summary><sectionid="method.partial_cmp"class="method trait-impl"><aclass="src rightside"href="../src/proc_macro2/lib.rs.html#1019-1021">Source</a><ahref="#method.partial_cmp"class="anchor"></a><h4class="code-header">fn <ahref="https://doc.rust-lang.org/1.89.0/core/cmp/trait.PartialOrd.html#tymethod.partial_cmp"class="fn">partial_cmp</a>(&self, other: &<aclass="struct"href="struct.Ident.html"title="struct proc_macro2::Ident">Ident</a>) -><aclass="enum"href="https://doc.rust-lang.org/1.89.0/core/option/enum.Option.html"title="enum core::option::Option">Option</a><<aclass="enum"href="https://doc.rust-lang.org/1.89.0/core/cmp/enum.Ordering.html"title="enum core::cmp::Ordering">Ordering</a>></h4></section></summary><divclass='docblock'>This method returns an ordering between <code>self</code> and <code>other</code> values if one exists. <ahref="https://doc.rust-lang.org/1.89.0/core/cmp/trait.PartialOrd.html#tymethod.partial_cmp">Read more</a></div></details><detailsclass="toggle method-toggle"open><summary><sectionid="method.lt"class="method trait-impl"><spanclass="rightside"><spanclass="since"title="Stable since Rust version 1.0.0">1.0.0</span> · <aclass="src"href="https://doc.rust-lang.org/1.89.0/src/core/cmp.rs.html#1384">Source</a></span><ahref="#method.lt"class="anchor"></a><h4class="code-header">fn <ahref="https://doc.rust-lang.org/1.89.0/core/cmp/trait.PartialOrd.html#method.lt"class="fn">lt</a>(&self, other: <aclass="primitive"href="https://doc.rust-lang.org/1.89.0/std/primitive.reference.html">&Rhs</a>) -><aclass="primitive"href="https://doc.rust-lang.org/1.89.0/std/primitive.bool.html">bool</a></h4></section></summary><divclass='docblock'>Tests less than (for <code>self</code> and <code>other</code>) and is used by the <code><</code> operator. <ahref="https://doc.rust-lang.org/1.89.0/core/cmp/trait.PartialOrd.html#method.lt">Read more</a></div></details><detailsclass="toggle method-toggle"open><summary><sectionid="method.le"class="method trait-impl"><spanclass="rightside"><spanclass="since"title="Stable since Rust version 1.0.0">1.0.0</span> · <aclass="src"href="https://doc.rust-lang.org/1.89.0/src/core/cmp.rs.html#1402">Source</a></span><ahref="#method.le"class="anchor"></a><h4class="code-header">fn <ahref="https://doc.rust-lang.org/1.89.0/core/cmp/trait.PartialOrd.html#method.le"class="fn">le</a>(&self, other: <aclass="primitive"href="https://doc.rust-lang.org/1.89.0/std/primitive.reference.html">&Rhs</a>) -><aclass="primitive"href="https://doc.rust-lang.org/1.89.0/std/primitive.bool.html">bool</a></h4></section></summary><divclass='docblock'>Tests less than or equal to (for <code>self</code> and <code>other</code>) and is used by the
<code><=</code> operator. <ahref="https://doc.rust-lang.org/1.89.0/core/cmp/trait.PartialOrd.html#method.le">Read more</a></div></details><detailsclass="toggle method-toggle"open><summary><sectionid="method.gt"class="method trait-impl"><spanclass="rightside"><spanclass="since"title="Stable since Rust version 1.0.0">1.0.0</span> · <aclass="src"href="https://doc.rust-lang.org/1.89.0/src/core/cmp.rs.html#1420">Source</a></span><ahref="#method.gt"class="anchor"></a><h4class="code-header">fn <ahref="https://doc.rust-lang.org/1.89.0/core/cmp/trait.PartialOrd.html#method.gt"class="fn">gt</a>(&self, other: <aclass="primitive"href="https://doc.rust-lang.org/1.89.0/std/primitive.reference.html">&Rhs</a>) -><aclass="primitive"href="https://doc.rust-lang.org/1.89.0/std/primitive.bool.html">bool</a></h4></section></summary><divclass='docblock'>Tests greater than (for <code>self</code> and <code>other</code>) and is used by the <code>></code>
operator. <ahref="https://doc.rust-lang.org/1.89.0/core/cmp/trait.PartialOrd.html#method.gt">Read more</a></div></details><detailsclass="toggle method-toggle"open><summary><sectionid="method.ge"class="method trait-impl"><spanclass="rightside"><spanclass="since"title="Stable since Rust version 1.0.0">1.0.0</span> · <aclass="src"href="https://doc.rust-lang.org/1.89.0/src/core/cmp.rs.html#1438">Source</a></span><ahref="#method.ge"class="anchor"></a><h4class="code-header">fn <ahref="https://doc.rust-lang.org/1.89.0/core/cmp/trait.PartialOrd.html#method.ge"class="fn">ge</a>(&self, other: <aclass="primitive"href="https://doc.rust-lang.org/1.89.0/std/primitive.reference.html">&Rhs</a>) -><aclass="primitive"href="https://doc.rust-lang.org/1.89.0/std/primitive.bool.html">bool</a></h4></section></summary><divclass='docblock'>Tests greater than or equal to (for <code>self</code> and <code>other</code>) and is used by
the <code>>=</code> operator. <ahref="https://doc.rust-lang.org/1.89.0/core/cmp/trait.PartialOrd.html#method.ge">Read more</a></div></details></div></details><sectionid="impl-Eq-for-Ident"class="impl"><aclass="src rightside"href="../src/proc_macro2/lib.rs.html#1016">Source</a><ahref="#impl-Eq-for-Ident"class="anchor"></a><h3class="code-header">impl <aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/cmp/trait.Eq.html"title="trait core::cmp::Eq">Eq</a> for <aclass="struct"href="struct.Ident.html"title="struct proc_macro2::Ident">Ident</a></h3></section></div><h2id="synthetic-implementations"class="section-header">Auto Trait Implementations<ahref="#synthetic-implementations"class="anchor"></a></h2><divid="synthetic-implementations-list"><sectionid="impl-Freeze-for-Ident"class="impl"><ahref="#impl-Freeze-for-Ident"class="anchor"></a><h3class="code-header">impl <aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/marker/trait.Freeze.html"title="trait core::marker::Freeze">Freeze</a> for <aclass="struct"href="struct.Ident.html"title="struct proc_macro2::Ident">Ident</a></h3></section><sectionid="impl-RefUnwindSafe-for-Ident"class="impl"><ahref="#impl-RefUnwindSafe-for-Ident"class="anchor"></a><h3class="code-header">impl <aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/panic/unwind_safe/trait.RefUnwindSafe.html"title="trait core::panic::unwind_safe::RefUnwindSafe">RefUnwindSafe</a> for <aclass="struct"href="struct.Ident.html"title="struct proc_macro2::Ident">Ident</a></h3></section><sectionid="impl-Send-for-Ident"class="impl"><ahref="#impl-Send-for-Ident"class="anchor"></a><h3class="code-header">impl !<aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/marker/trait.Send.html"title="trait core::marker::Send">Send</a> for <aclass="struct"href="struct.Ident.html"title="struct proc_macro2::Ident">Ident</a></h3></section><sectionid="impl-Sync-for-Ident"class="impl"><ahref="#impl-Sync-for-Ident"class="anchor"></a><h3class="code-header">impl !<aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/marker/trait.Sync.html"title="trait core::marker::Sync">Sync</a> for <aclass="struct"href="struct.Ident.html"title="struct proc_macro2::Ident">Ident</a></h3></section><sectionid="impl-Unpin-for-Ident"class="impl"><ahref="#impl-Unpin-for-Ident"class="anchor"></a><h3class="code-header">impl <aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/marker/trait.Unpin.html"title="trait core::marker::Unpin">Unpin</a> for <aclass="struct"href="struct.Ident.html"title="struct proc_macro2::Ident">Ident</a></h3></section><sectionid="impl-UnwindSafe-for-Ident"class="impl"><ahref="#impl-UnwindSafe-for-Ident"class="anchor"></a><h3class="code-header">impl <aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/panic/unwind_safe/trait.UnwindSafe.html"title="trait core::panic::unwind_safe::UnwindSafe">UnwindSafe</a> for <aclass="struct"href="struct.Ident.html"title="struct proc_macro2::Ident">Ident</a></h3></section></div><h2id="blanket-implementations"class="section-header">Blanket Implementations<ahref="#blanket-implementations"class="anchor"></a></h2><divid="blanket-implementations-list"><detailsclass="toggle implementors-toggle"><summary><sectionid="impl-Any-for-T"class="impl"><aclass="src rightside"href="https://doc.rust-lang.org/1.89.0/src/core/any.rs.html#138">Source</a><ahref="#impl-Any-for-T"class="anchor"></a><h3class="code-header">impl<T><aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/any/trait.Any.html"title="trait core::any::Any">Any</a> for T<divclass="where">where
T: 'static + ?<aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/marker/trait.Sized.html"title="trait core::marker::Sized">Sized</a>,</div></h3></section></summary><divclass="impl-items"><detailsclass="toggle method-toggle"open><summary><sectionid="method.type_id"class="method trait-impl"><aclass="src rightside"href="https://doc.rust-lang.org/1.89.0/src/core/any.rs.html#139">Source</a><ahref="#method.type_id"class="anchor"></a><h4class="code-header">fn <ahref="https://doc.rust-lang.org/1.89.0/core/any/trait.Any.html#tymethod.type_id"class="fn">type_id</a>(&self) -><aclass="struct"href="https://doc.rust-lang.org/1.89.0/core/any/struct.TypeId.html"title="struct core::any::TypeId">TypeId</a></h4></section></summary><divclass='docblock'>Gets the <code>TypeId</code> of <code>self</code>. <ahref="https://doc.rust-lang.org/1.89.0/core/any/trait.Any.html#tymethod.type_id">Read more</a></div></details></div></details><detailsclass="toggle implementors-toggle"><summary><sectionid="impl-Borrow%3CT%3E-for-T"class="impl"><aclass="src rightside"href="https://doc.rust-lang.org/1.89.0/src/core/borrow.rs.html#209">Source</a><ahref="#impl-Borrow%3CT%3E-for-T"class="anchor"></a><h3class="code-header">impl<T><aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/borrow/trait.Borrow.html"title="trait core::borrow::Borrow">Borrow</a><T> for T<divclass="where">where
T: ?<aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/marker/trait.Sized.html"title="trait core::marker::Sized">Sized</a>,</div></h3></section></summary><divclass="impl-items"><detailsclass="toggle method-toggle"open><summary><sectionid="method.borrow"class="method trait-impl"><aclass="src rightside"href="https://doc.rust-lang.org/1.89.0/src/core/borrow.rs.html#211">Source</a><ahref="#method.borrow"class="anchor"></a><h4class="code-header">fn <ahref="https://doc.rust-lang.org/1.89.0/core/borrow/trait.Borrow.html#tymethod.borrow"class="fn">borrow</a>(&self) -><aclass="primitive"href="https://doc.rust-lang.org/1.89.0/std/primitive.reference.html">&T</a></h4></section></summary><divclass='docblock'>Immutably borrows from an owned value. <ahref="https://doc.rust-lang.org/1.89.0/core/borrow/trait.Borrow.html#tymethod.borrow">Read more</a></div></details></div></details><detailsclass="toggle implementors-toggle"><summary><sectionid="impl-BorrowMut%3CT%3E-for-T"class="impl"><aclass="src rightside"href="https://doc.rust-lang.org/1.89.0/src/core/borrow.rs.html#217">Source</a><ahref="#impl-BorrowMut%3CT%3E-for-T"class="anchor"></a><h3class="code-header">impl<T><aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/borrow/trait.BorrowMut.html"title="trait core::borrow::BorrowMut">BorrowMut</a><T> for T<divclass="where">where
T: ?<aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/marker/trait.Sized.html"title="trait core::marker::Sized">Sized</a>,</div></h3></section></summary><divclass="impl-items"><detailsclass="toggle method-toggle"open><summary><sectionid="method.borrow_mut"class="method trait-impl"><aclass="src rightside"href="https://doc.rust-lang.org/1.89.0/src/core/borrow.rs.html#218">Source</a><ahref="#method.borrow_mut"class="anchor"></a><h4class="code-header">fn <ahref="https://doc.rust-lang.org/1.89.0/core/borrow/trait.BorrowMut.html#tymethod.borrow_mut"class="fn">borrow_mut</a>(&mut self) -><aclass="primitive"href="https://doc.rust-lang.org/1.89.0/std/primitive.reference.html">&mut T</a></h4></section></summary><divclass='docblock'>Mutably borrows from an owned value. <ahref="https://doc.rust-lang.org/1.89.0/core/borrow/trait.BorrowMut.html#tymethod.borrow_mut">Read more</a></div></details></div></details><detailsclass="toggle implementors-toggle"><summary><sectionid="impl-CloneToUninit-for-T"class="impl"><aclass="src rightside"href="https://doc.rust-lang.org/1.89.0/src/core/clone.rs.html#483">Source</a><ahref="#impl-CloneToUninit-for-T"class="anchor"></a><h3class="code-header">impl<T><aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/clone/trait.CloneToUninit.html"title="trait core::clone::CloneToUninit">CloneToUninit</a> for T<divclass="where">where
T: <aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/clone/trait.Clone.html"title="trait core::clone::Clone">Clone</a>,</div></h3></section></summary><divclass="impl-items"><detailsclass="toggle method-toggle"open><summary><sectionid="method.clone_to_uninit"class="method trait-impl"><aclass="src rightside"href="https://doc.rust-lang.org/1.89.0/src/core/clone.rs.html#485">Source</a><ahref="#method.clone_to_uninit"class="anchor"></a><h4class="code-header">unsafe fn <ahref="https://doc.rust-lang.org/1.89.0/core/clone/trait.CloneToUninit.html#tymethod.clone_to_uninit"class="fn">clone_to_uninit</a>(&self, dest: <aclass="primitive"href="https://doc.rust-lang.org/1.89.0/std/primitive.pointer.html">*mut </a><aclass="primitive"href="https://doc.rust-lang.org/1.89.0/std/primitive.u8.html">u8</a>)</h4></section></summary><spanclass="item-info"><divclass="stab unstable"><spanclass="emoji">🔬</span><span>This is a nightly-only experimental API. (<code>clone_to_uninit</code>)</span></div></span><divclass='docblock'>Performs copy-assignment from <code>self</code> to <code>dest</code>. <ahref="https://doc.rust-lang.org/1.89.0/core/clone/trait.CloneToUninit.html#tymethod.clone_to_uninit">Read more</a></div></details></div></details><detailsclass="toggle implementors-toggle"><summary><sectionid="impl-From%3CT%3E-for-T"class="impl"><aclass="src rightside"href="https://doc.rust-lang.org/1.89.0/src/core/convert/mod.rs.html#774">Source</a><ahref="#impl-From%3CT%3E-for-T"class="anchor"></a><h3class="code-header">impl<T><aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/convert/trait.From.html"title="trait core::convert::From">From</a><T> for T</h3></section></summary><divclass="impl-items"><detailsclass="toggle method-toggle"open><summary><sectionid="method.from-1"class="method trait-impl"><aclass="src rightside"href="https://doc.rust-lang.org/1.89.0/src/core/convert/mod.rs.html#777">Source</a><ahref="#method.from-1"class="anchor"></a><h4class="code-header">fn <ahref="https://doc.rust-lang.org/1.89.0/core/convert/trait.From.html#tymethod.from"class="fn">from</a>(t: T) -> T</h4></section></summary><divclass="docblock"><p>Returns the argument unchanged.</p>
</div></details></div></details><detailsclass="toggle implementors-toggle"><summary><sectionid="impl-Into%3CU%3E-for-T"class="impl"><aclass="src rightside"href="https://doc.rust-lang.org/1.89.0/src/core/convert/mod.rs.html#757-759">Source</a><ahref="#impl-Into%3CU%3E-for-T"class="anchor"></a><h3class="code-header">impl<T, U><aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/convert/trait.Into.html"title="trait core::convert::Into">Into</a><U> for T<divclass="where">where
<code><ahref="https://doc.rust-lang.org/1.89.0/core/convert/trait.From.html"title="trait core::convert::From">From</a><T> for U</code> chooses to do.</p>
</div></details></div></details><detailsclass="toggle implementors-toggle"><summary><sectionid="impl-ToOwned-for-T"class="impl"><aclass="src rightside"href="https://doc.rust-lang.org/1.89.0/src/alloc/borrow.rs.html#82-84">Source</a><ahref="#impl-ToOwned-for-T"class="anchor"></a><h3class="code-header">impl<T><aclass="trait"href="https://doc.rust-lang.org/1.89.0/alloc/borrow/trait.ToOwned.html"title="trait alloc::borrow::ToOwned">ToOwned</a> for T<divclass="where">where
T: <aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/clone/trait.Clone.html"title="trait core::clone::Clone">Clone</a>,</div></h3></section></summary><divclass="impl-items"><detailsclass="toggle"open><summary><sectionid="associatedtype.Owned"class="associatedtype trait-impl"><aclass="src rightside"href="https://doc.rust-lang.org/1.89.0/src/alloc/borrow.rs.html#86">Source</a><ahref="#associatedtype.Owned"class="anchor"></a><h4class="code-header">type <ahref="https://doc.rust-lang.org/1.89.0/alloc/borrow/trait.ToOwned.html#associatedtype.Owned"class="associatedtype">Owned</a> = T</h4></section></summary><divclass='docblock'>The resulting type after obtaining ownership.</div></details><detailsclass="toggle method-toggle"open><summary><sectionid="method.to_owned"class="method trait-impl"><aclass="src rightside"href="https://doc.rust-lang.org/1.89.0/src/alloc/borrow.rs.html#87">Source</a><ahref="#method.to_owned"class="anchor"></a><h4class="code-header">fn <ahref="https://doc.rust-lang.org/1.89.0/alloc/borrow/trait.ToOwned.html#tymethod.to_owned"class="fn">to_owned</a>(&self) -> T</h4></section></summary><divclass='docblock'>Creates owned data from borrowed data, usually by cloning. <ahref="https://doc.rust-lang.org/1.89.0/alloc/borrow/trait.ToOwned.html#tymethod.to_owned">Read more</a></div></details><detailsclass="toggle method-toggle"open><summary><sectionid="method.clone_into"class="method trait-impl"><aclass="src rightside"href="https://doc.rust-lang.org/1.89.0/src/alloc/borrow.rs.html#91">Source</a><ahref="#method.clone_into"class="anchor"></a><h4class="code-header">fn <ahref="https://doc.rust-lang.org/1.89.0/alloc/borrow/trait.ToOwned.html#method.clone_into"class="fn">clone_into</a>(&self, target: <aclass="primitive"href="https://doc.rust-lang.org/1.89.0/std/primitive.reference.html">&mut T</a>)</h4></section></summary><divclass='docblock'>Uses borrowed data to replace owned data, usually by cloning. <ahref="https://doc.rust-lang.org/1.89.0/alloc/borrow/trait.ToOwned.html#method.clone_into">Read more</a></div></details></div></details><detailsclass="toggle implementors-toggle"><summary><sectionid="impl-ToString-for-T"class="impl"><aclass="src rightside"href="https://doc.rust-lang.org/1.89.0/src/alloc/string.rs.html#2805">Source</a><ahref="#impl-ToString-for-T"class="anchor"></a><h3class="code-header">impl<T><aclass="trait"href="https://doc.rust-lang.org/1.89.0/alloc/string/trait.ToString.html"title="trait alloc::string::ToString">ToString</a> for T<divclass="where">where
T: <aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/fmt/trait.Display.html"title="trait core::fmt::Display">Display</a> + ?<aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/marker/trait.Sized.html"title="trait core::marker::Sized">Sized</a>,</div></h3></section></summary><divclass="impl-items"><detailsclass="toggle method-toggle"open><summary><sectionid="method.to_string"class="method trait-impl"><aclass="src rightside"href="https://doc.rust-lang.org/1.89.0/src/alloc/string.rs.html#2807">Source</a><ahref="#method.to_string"class="anchor"></a><h4class="code-header">fn <ahref="https://doc.rust-lang.org/1.89.0/alloc/string/trait.ToString.html#tymethod.to_string"class="fn">to_string</a>(&self) -><aclass="struct"href="https://doc.rust-lang.org/1.89.0/alloc/string/struct.String.html"title="struct alloc::string::String">String</a></h4></section></summary><divclass='docblock'>Converts the given value to a <code>String</code>. <ahref="https://doc.rust-lang.org/1.89.0/alloc/string/trait.ToString.html#tymethod.to_string">Read more</a></div></details></div></details><detailsclass="toggle implementors-toggle"><summary><sectionid="impl-TryFrom%3CU%3E-for-T"class="impl"><aclass="src rightside"href="https://doc.rust-lang.org/1.89.0/src/core/convert/mod.rs.html#813-815">Source</a><ahref="#impl-TryFrom%3CU%3E-for-T"class="anchor"></a><h3class="code-header">impl<T, U><aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/convert/trait.TryFrom.html"title="trait core::convert::TryFrom">TryFrom</a><U> for T<divclass="where">where
U: <aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/convert/trait.Into.html"title="trait core::convert::Into">Into</a><T>,</div></h3></section></summary><divclass="impl-items"><detailsclass="toggle"open><summary><sectionid="associatedtype.Error-1"class="associatedtype trait-impl"><aclass="src rightside"href="https://doc.rust-lang.org/1.89.0/src/core/convert/mod.rs.html#817">Source</a><ahref="#associatedtype.Error-1"class="anchor"></a><h4class="code-header">type <ahref="https://doc.rust-lang.org/1.89.0/core/convert/trait.TryFrom.html#associatedtype.Error"class="associatedtype">Error</a> = <aclass="enum"href="https://doc.rust-lang.org/1.89.0/core/convert/enum.Infallible.html"title="enum core::convert::Infallible">Infallible</a></h4></section></summary><divclass='docblock'>The type returned in the event of a conversion error.</div></details><detailsclass="toggle method-toggle"open><summary><sectionid="method.try_from"class="method trait-impl"><aclass="src rightside"href="https://doc.rust-lang.org/1.89.0/src/core/convert/mod.rs.html#820">Source</a><ahref="#method.try_from"class="anchor"></a><h4class="code-header">fn <ahref="https://doc.rust-lang.org/1.89.0/core/convert/trait.TryFrom.html#tymethod.try_from"class="fn">try_from</a>(value: U) -><aclass="enum"href="https://doc.rust-lang.org/1.89.0/core/result/enum.Result.html"title="enum core::result::Result">Result</a><T, <T as <aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/convert/trait.TryFrom.html"title="trait core::convert::TryFrom">TryFrom</a><U>>::<aclass="associatedtype"href="https://doc.rust-lang.org/1.89.0/core/convert/trait.TryFrom.html#associatedtype.Error"title="type core::convert::TryFrom::Error">Error</a>></h4></section></summary><divclass='docblock'>Performs the conversion.</div></details></div></details><detailsclass="toggle implementors-toggle"><summary><sectionid="impl-TryInto%3CU%3E-for-T"class="impl"><aclass="src rightside"href="https://doc.rust-lang.org/1.89.0/src/core/convert/mod.rs.html#798-800">Source</a><ahref="#impl-TryInto%3CU%3E-for-T"class="anchor"></a><h3class="code-header">impl<T, U><aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/convert/trait.TryInto.html"title="trait core::convert::TryInto">TryInto</a><U> for T<divclass="where">where
U: <aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/convert/trait.TryFrom.html"title="trait core::convert::TryFrom">TryFrom</a><T>,</div></h3></section></summary><divclass="impl-items"><detailsclass="toggle"open><summary><sectionid="associatedtype.Error"class="associatedtype trait-impl"><aclass="src rightside"href="https://doc.rust-lang.org/1.89.0/src/core/convert/mod.rs.html#802">Source</a><ahref="#associatedtype.Error"class="anchor"></a><h4class="code-header">type <ahref="https://doc.rust-lang.org/1.89.0/core/convert/trait.TryInto.html#associatedtype.Error"class="associatedtype">Error</a> = <U as <aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/convert/trait.TryFrom.html"title="trait core::convert::TryFrom">TryFrom</a><T>>::<aclass="associatedtype"href="https://doc.rust-lang.org/1.89.0/core/convert/trait.TryFrom.html#associatedtype.Error"title="type core::convert::TryFrom::Error">Error</a></h4></section></summary><divclass='docblock'>The type returned in the event of a conversion error.</div></details><detailsclass="toggle method-toggle"open><summary><sectionid="method.try_into"class="method trait-impl"><aclass="src rightside"href="https://doc.rust-lang.org/1.89.0/src/core/convert/mod.rs.html#805">Source</a><ahref="#method.try_into"class="anchor"></a><h4class="code-header">fn <ahref="https://doc.rust-lang.org/1.89.0/core/convert/trait.TryInto.html#tymethod.try_into"class="fn">try_into</a>(self) -><aclass="enum"href="https://doc.rust-lang.org/1.89.0/core/result/enum.Result.html"title="enum core::result::Result">Result</a><U, <U as <aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/convert/trait.TryFrom.html"title="trait core::convert::TryFrom">TryFrom</a><T>>::<aclass="associatedtype"href="https://doc.rust-lang.org/1.89.0/core/convert/trait.TryFrom.html#associatedtype.Error"title="type core::convert::TryFrom::Error">Error</a>></h4></section></summary><divclass='docblock'>Performs the conversion.</div></details></div></details></div></section></div></main></body></html>